@@ -54,8 +54,10 @@ dbColumn <- function(conn, name, colname, action = c("add", "drop"),
         message("--")
     }
     ## Execute the query
-    if (exec)
+    if (exec) {
+        dbConnCheck(conn)
         dbSendQuery(conn, tmp.query)
+    }
     ## Return TRUE
     return(TRUE)
 }
