@@ -8,8 +8,8 @@
 ##' @param name A character string specifying a PostgreSQL table, view
 ##'     or schema name.
 ##' @param comment A character string specifying the comment.
-##' @param type The type of the object to comment, either \code{table}
-##'     or \code{view}
+##' @param type The type of the object to comment, either \code{table}, \code{view},
+##'     or \code{schema}
 ##' @param display Logical. Whether to display the query (defaults to
 ##'     \code{TRUE}).
 ##' @param exec Logical. Whether to execute the query (defaults to
@@ -51,8 +51,10 @@ dbComment <- function(conn, name, comment, type = c("table",
         message("--")
     }
     ## Execute the query
-    if (exec)
+    if (exec) {
+        dbConnCheck(conn)
         dbSendQuery(conn, tmp.query)
+    }
     ## Return nothing
     return(TRUE)
 }
