@@ -7,8 +7,8 @@
 ##' @param conn A connection object.
 ##' @param name A character string specifying a PostgreSQL table, view
 ##'     or schema name.
-##' @param type The type of the object to comment, either \code{table}
-##'     or \code{view}
+##' @param type The type of the object to drop, either \code{table}, \code{view},
+##'     or \code{schema}.
 ##' @param ifexists Do not throw an error if the table does not
 ##'     exist. A notice is issued in this case.
 ##' @param cascade Automatically drop objects that depend on the table
@@ -56,8 +56,10 @@ dbDrop <- function(conn, name, type = c("table", "view", "schema"),
         message("--")
     }
     ## Execute the query
-    if (exec)
+    if (exec) {
+        dbConnCheck(conn)
         dbSendQuery(conn, tmp.query)
+    }
     ## Return nothing
     return(TRUE)
 }
