@@ -70,8 +70,10 @@ dbIndex <- function(conn, name, colname, idxname, unique = FALSE,
         message("--")
     }
     ## Execute the query
-    if (exec)
+    if (exec) {
+        dbConnCheck(conn)
         dbSendQuery(conn, tmp.query)
+    }
     ## Return TRUE
     return(TRUE)
 }
