@@ -50,8 +50,10 @@ dbVacuum <- function(conn, name, full = FALSE, verbose = FALSE,
         message("--")
     }
     ## Execute the query
-    if (exec)
+    if (exec) {
+        dbConnCheck(conn)
         dbSendQuery(conn, tmp.query)
+    }
     ## Return TRUE
     return(TRUE)
 }
