@@ -112,6 +112,7 @@
 pgInsert <- function(conn, name, data.obj, geom = "geom", partial.match = FALSE, 
     overwrite = FALSE, new.id = NULL, upsert.using = NULL, alter.names = TRUE, encoding = NULL, 
     return.pgi = FALSE) {
+    dbConnCheck(conn)
     ## Check if PostGIS installed
     if (!suppressMessages(pgPostGIS(conn))) {
         stop("PostGIS is not enabled on this database.")
@@ -177,7 +178,7 @@ pgInsert <- function(conn, name, data.obj, geom = "geom", partial.match = FALSE,
     }
     ## Create table if specified
     if (!is.null(pgi$db.new.table)) {
-        if (overwrite) {
+        if (overwrite & exists.t) {
             over.t <- dbDrop(conn, name = name, type = "table", 
                 ifexists = TRUE)
             if (!over.t) {
